utils

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DefaultIfZero

func DefaultIfZero[T comparable](value, fallback T) T

DefaultIfZero returns fallback when value is the zero value.

func PtrIfNonZero

func PtrIfNonZero[T interface{ IsZero() bool }](v T) *T

PtrIfNonZero returns nil when the value reports itself as zero.

Types

This section is empty.

Jump to